@@ -8,9 +8,9 @@ core <- c(
   "ggplot2",
   "tsibble",
   "tsibbledata",
+  "ggtime",
   "feasts",
-  "fable",
-  "fabletools"
+  "fable"
 )
 
 core_unloaded <- function() {
